package com.ynet.life.net.ftp;

import com.ynet.gene.service.GENEService;
import com.ynet.life.base.LifeConstants;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.StringTokenizer;
import org.apache.commons.net.ftp.FTPClient;
import org.apache.commons.net.ftp.FTPReply;

/* loaded from: com_ynet_life_net_ftp.jar:com/ynet/life/net/ftp/FtpService.class */
public class FtpService extends GENEService {
    private String ftpServerAddress = null;
    private int port = 21;
    private String user = null;
    private String password = null;
    private int timeout = 0;
    private static final TranFailException EXCEPTION_LOGIN = new TranFailException("EBLN0000", "FTP服务器登录失败");
    private static final TranFailException EXCEPTION_FILE_TRANSFER = new TranFailException("EBLN0000", "文件传输失败");
    private static final TranFailException EXCEPTION_GENERAL = new TranFailException("EBLN0000", "FTP IO异常");

    public FTPClient initConnection() throws TranFailException {
        FTPClient ftp = new FTPClient();
        try {
            ftp.connect(this.ftpServerAddress, this.port);
            if (!FTPReply.isPositiveCompletion(ftp.getReplyCode())) {
                ftp.disconnect();
                throw new TranFailException("EBLN0000", "FTP服务器连接失败");
            }
            if (!ftp.login(this.user, this.password)) {
                throw EXCEPTION_LOGIN;
            }
            ftp.enterLocalPassiveMode();
            ftp.setDataTimeout(this.timeout);
            Trace.logDebug("LifeFTP", "FTP服务器[" + this.ftpServerAddress + " : " + this.port + "]登录成功");
            return ftp;
        } catch (TranFailException te) {
            Trace.logError("LifeFTP", te.getShowMessage(), te);
            throw te;
        } catch (IOException ioe) {
            Trace.logError("LifeFTP", EXCEPTION_LOGIN.getShowMessage(), ioe);
            throw EXCEPTION_LOGIN;
        }
    }

    public void setTransferMode(FTPClient ftp, boolean binaryFile) throws TranFailException {
        try {
            if (binaryFile) {
                ftp.setFileType(2);
                Trace.logDebug("LifeFTP", "FTP文件传输方式为：二进制");
            } else {
                ftp.setFileType(0);
                Trace.logDebug("LifeFTP", "FTP文件传输方式为：ASCII");
            }
        } catch (IOException ex) {
            Trace.logError("LifeFTP", EXCEPTION_GENERAL.getShowMessage(), ex);
            throw EXCEPTION_GENERAL;
        }
    }

    public void makeMultiDirectory(FTPClient ftp, String dir) throws TranFailException {
        try {
            StringBuffer fullDirectory = new StringBuffer();
            StringTokenizer toke = new StringTokenizer(dir, "/");
            while (toke.hasMoreElements()) {
                String currentDirectory = (String) toke.nextElement();
                fullDirectory.append(currentDirectory);
                ftp.makeDirectory(fullDirectory.toString());
                if (toke.hasMoreElements()) {
                    fullDirectory.append('/');
                }
            }
        } catch (IOException ex) {
            Trace.logError("LifeFTP", EXCEPTION_GENERAL.getShowMessage(), ex);
            throw EXCEPTION_GENERAL;
        }
    }

    public void changeWorkingDirectory(FTPClient ftp, String dir) throws TranFailException {
        try {
            if (!ftp.changeWorkingDirectory(dir)) {
                throw new TranFailException("EBLN0000", "目录[ " + dir + "]进入失败");
            }
        } catch (IOException ioe) {
            Trace.logError("LifeFTP", EXCEPTION_GENERAL.getShowMessage(), ioe);
            throw EXCEPTION_GENERAL;
        } catch (TranFailException tfe) {
            Trace.logError("LifeFTP", tfe.getShowMessage(), tfe);
            throw tfe;
        }
    }

    public void uploadFile(FTPClient ftp, String localFilePathName, String remoteFilePathName) throws TranFailException {
        InputStream input = null;
        try {
            try {
                InputStream input2 = new FileInputStream(localFilePathName);
                if (!ftp.storeFile(remoteFilePathName, input2)) {
                    throw EXCEPTION_FILE_TRANSFER;
                }
                Trace.logDebug("LifeFTP", "文件成功上传到FTP服务器");
                try {
                    input2.close();
                } catch (IOException ex) {
                    Trace.logWarning("LifeFTP", "FTP对象关闭异常", ex);
                }
            } catch (Throwable th) {
                if (0 != 0) {
                    try {
                        input.close();
                    } catch (IOException ex2) {
                        Trace.logWarning("LifeFTP", "FTP对象关闭异常", ex2);
                    }
                }
                throw th;
            }
        } catch (IOException ioe) {
            Trace.logError("LifeFTP", EXCEPTION_FILE_TRANSFER.getShowMessage(), ioe);
            throw EXCEPTION_FILE_TRANSFER;
        } catch (TranFailException tfe) {
            Trace.logError("LifeFTP", tfe.getShowMessage(), tfe);
            throw tfe;
        }
    }

    public void downloadFile(FTPClient ftp, String remoteFilePathName, String localFilePathName) throws TranFailException {
        OutputStream output = null;
        try {
            try {
                OutputStream output2 = new FileOutputStream(localFilePathName);
                boolean downloadResult = ftp.retrieveFile(remoteFilePathName, output2);
                if (!downloadResult) {
                    throw LifeConstants.EXCEPTION_FILE_NOT_FOUND;
                }
                Trace.logDebug("LifeFTP", "文件成功从FTP服务器下载");
                try {
                    output2.close();
                    if (!downloadResult) {
                        new File(localFilePathName).delete();
                    }
                } catch (IOException ex) {
                    Trace.logWarning("LifeFTP", "FTP对象关闭异常", ex);
                }
            } catch (TranFailException tfe) {
                Trace.logError("LifeFTP", tfe.getShowMessage(), tfe);
                throw tfe;
            } catch (IOException ex2) {
                Trace.logError("LifeFTP", EXCEPTION_FILE_TRANSFER.getShowMessage(), ex2);
                throw EXCEPTION_FILE_TRANSFER;
            }
        } catch (Throwable th) {
            if (0 != 0) {
                try {
                    output.close();
                } catch (IOException ex3) {
                    Trace.logWarning("LifeFTP", "FTP对象关闭异常", ex3);
                    throw th;
                }
            }
            if (0 == 0) {
                new File(localFilePathName).delete();
            }
            throw th;
        }
    }

    public void setFtpServerAddress(String ftpServerAddress) {
        this.ftpServerAddress = ftpServerAddress;
    }

    public void setUser(String user) {
        this.user = user;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public void setTimeout(String timeout) {
        try {
            this.timeout = Integer.parseInt(timeout);
        } catch (NumberFormatException unused) {
            this.timeout = 500;
        }
    }

    public void setPort(String port) {
        try {
            this.port = Integer.parseInt(port);
        } catch (NumberFormatException unused) {
            this.port = 21;
        }
    }
}
